Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.

`0.1.1`_ - 2021-12-29
---------------------

Changed
~~~~~~~

* Update project files.

`0.1b0`_ - 2021-05-30
---------------------

Added
~~~~~
- Create order forms.
- Send order information via email.
- Manage order status.
- Generate reports, address and barcode labels.

.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html

.. _0.1b0: https://edugit.org/hansegucker/AlekSIS-App-Order/-/tags/0.1b0
.. _0.1.1: https://edugit.org/hansegucker/AlekSIS-App-Order/-/tags/0.1.1
